---
title: dCTPdeaminase
layout: article
tableColumns:
    article:
      doi: 10.1016/j.cell.2021.09.031
      abstract: |
        The cyclic pyrimidines 3',5'-cyclic cytidine monophosphate (cCMP) and 3',5'-cyclic uridine monophosphate (cUMP) have been reported in multiple organisms and cell types. As opposed to the cyclic nucleotides 3',5'-cyclic adenosine monophosphate (cAMP) and 3',5'-cyclic guanosine monophosphate (cGMP), which are second messenger molecules with well-established regulatory roles across all domains of life, the biological role of cyclic pyrimidines has remained unclear. Here we report that cCMP and cUMP are second messengers functioning in bacterial immunity against viruses. We discovered a family of bacterial pyrimidine cyclase enzymes that specifically synthesize cCMP and cUMP following phage infection and demonstrate that these molecules activate immune effectors that execute an antiviral response. A crystal structure of a uridylate cyclase enzyme from this family explains the molecular mechanism of selectivity for pyrimidines as cyclization substrates. Defense systems encoding pyrimidine cyclases, denoted here Pycsar (pyrimidine cyclase system for antiphage resistance), are widespread in prokaryotes. Our results assign clear biological function to cCMP and cUMP as immunity signaling molecules in bacteria.
    Sensor: Monitoring of the host cell machinery integrity
    Activator: Direct
    Effector: Nucleotide modifying
    PFAM: PF00383, PF14437
---

# dCTPdeaminase
## Description
dCTPdeaminase is a family of systems. dCTPdeaminase from Escherichia coli has been shown to provide resistance against various lytic phages when express heterologously in another Escherichia coli.
This system is mostly found in Proteobacteria but a few examples also exist in Acidobacteria, Actinobacteria, Bacteroidetes, Cyanobacteria, Firmicutes, Planctomyces, and Verrucomicrobia.
Those systems can be found in plasmids (around 8%).

## Mechanism
When activated by a phage infection, dCTPdeaminase, will convert deoxycytidine (dCTP/dCDP/dCMP) into deoxyuridine.
This action will deplete the pool of CTP nucleotide necessary for the phage replication and will stop the infection.
The trigger for dCTPdeaminase may be linked to the shutoff of RNAP (ÏƒS-dependent host RNA polymerase) that occur during phage infections.

## Example of genomic structure

The dCTPdeaminase system is composed of one protein: dCTPdeaminase.

Here is an example found in the RefSeq database: 

![dctpdeaminase](/dctpdeaminase/dCTPdeaminase.svg){max-width=750px}

dCTPdeaminase system in the genome of *Vibrio parahaemolyticus* (GCF_009883855.1) is composed of 1 protein: dCTPdeaminase (WP_029845369.1).

## Distribution of the system among prokaryotes

The dCTPdeaminase system is present in a total of 269 different species.

Among the 22k complete genomes of RefSeq, this system is present in 501 genomes (2.2 %).

![dctpdeaminase](/dctpdeaminase/Distribution_dCTPdeaminase.svg){max-width=750px}

*Proportion of genome encoding the dCTPdeaminase system for the 14 phyla with more than 50 genomes in the RefSeq database.* 

## Structure

### dCTPdeaminase

::molstar-pdbe-plugin
---
height: 700
dataUrl: /dctpdeaminase/dCTPdeaminase__dCTPdeaminase-plddts_91.37723.pdb
---
::

## Experimental validation
<mermaid>
graph LR;
    Tal_2022[<a href='https://doi.org/10.1038/s41564-022-01158-0'>Tal et al., 2022</a>] --> Origin_0
    Origin_0[Escherichia coli 
<a href='https://ncbi.nlm.nih.gov/protein/WP_045268677.1'>WP_045268677.1</a>] --> Expressed_0[Escherichia coli]
    Expressed_0[Escherichia coli] ----> T5 & SECphi4 & SECphi6 & SECphi18 & T2 & T4 & T6 & T7
    Hsueh_2022[<a href='https://doi.org/10.1038/s41564-022-01162-4'>Hsueh et al., 2022</a>] --> Origin_1
    Origin_1[ AvcID
Escherichia coli 
<a href='https://ncbi.nlm.nih.gov/protein/WP_096882215.1'>WP_096882215.1</a>] --> Expressed_1[Escherichia coli]
    Expressed_1[Escherichia coli] ----> T3 & SECphi17 & SECphi18 & SECphi27
    Hsueh_2022[<a href='https://doi.org/10.1038/s41564-022-01162-4'>Hsueh et al., 2022</a>] --> Origin_2
    Origin_2[ AvcID
Proteus mirabilis 
<a href='https://ncbi.nlm.nih.gov/protein/WP_108717204.1'>WP_108717204.1</a>] --> Expressed_2[Escherichia coli]
    Expressed_2[Escherichia coli] ----> T4
    Hsueh_2022[<a href='https://doi.org/10.1038/s41564-022-01162-4'>Hsueh et al., 2022</a>] --> Origin_3
    Origin_3[ AvcID
Vibrio parahaemolyticus 
<a href='https://ncbi.nlm.nih.gov/protein/WP_020839904.1'>WP_020839904.1</a>] --> Expressed_3[Escherichia coli]
    Expressed_3[Escherichia coli] ----> T3 & T5 & T6 & SECphi18
    Hsueh_2022[<a href='https://doi.org/10.1038/s41564-022-01162-4'>Hsueh et al., 2022</a>] --> Origin_4
    Origin_4[ AvcID
Vibrio cholerae 
<a href='https://ncbi.nlm.nih.gov/protein/WP_001901328.1'>WP_001901328.1</a>] --> Expressed_4[Escherichia coli]
    Expressed_4[Escherichia coli] ----> T2 & T3
    subgraph Title1[Reference]
        Tal_2022
        Hsueh_2022
end
    subgraph Title2[System origin]
        Origin_0
        Origin_1
        Origin_2
        Origin_3
        Origin_4
end
    subgraph Title3[Expression species]
        Expressed_0
        Expressed_1
        Expressed_2
        Expressed_3
        Expressed_4
end
    subgraph Title4[Phage infected]
        T5
        SECphi4
        SECphi6
        SECphi18
        T2
        T4
        T6
        T7
        T3
        SECphi17
        SECphi18
        SECphi27
        T4
        T3
        T5
        T6
        SECphi18
        T2
        T3
end
    style Title1 fill:none,stroke:none,stroke-width:none
    style Title2 fill:none,stroke:none,stroke-width:none
    style Title3 fill:none,stroke:none,stroke-width:none
    style Title4 fill:none,stroke:none,stroke-width:none
</mermaid>
## Relevant abstracts

::relevant-abstracts
---
items:
    - doi: 10.1038/s41564-022-01162-4
---
::

